internal

package
v0.0.0-...-3789c44 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 23, 2022 License: Unlicense Imports: 5 Imported by: 0

Documentation

Overview

Package internal contains the bubbletea model and its helper

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewModel

func NewModel(pattern string, w, s, l int) *model

NewModel returns an initial model according to given params

func Tick

func Tick() tea.Cmd

Tick returns a tea.Cmd that returns a tickMsg every 1 second

Types

This section is empty.

Jump to