package
Version:
v0.0.0-...-3789c44
Opens a new window with list of versions in this module.
Published: Oct 23, 2022
License: Unlicense
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package internal contains the bubbletea model and its helper
func NewModel(pattern string, w, s, l int) *model
NewModel returns an initial model according to given params
Tick returns a tea.Cmd that returns a tickMsg every 1 second
Source Files
¶
Click to show internal directories.
Click to hide internal directories.